# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import maintenance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_maintenance__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/compute/v1/instance_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a)yandex/cloud/compute/v1/maintenance.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"l\n\x12GetInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04view\x18\x02 \x01(\x0e\x32%.yandex.cloud.compute.v1.InstanceView\"\xae\x01\n\x14ListInstancesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"f\n\x15ListInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd2\x0c\n\x15\x43reateInstanceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1d\n\x07zone_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x0bplatform_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x44\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12N\n\x08metadata\x18\x08 \x03(\x0b\x32<.yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry\x12\x42\n\x10metadata_options\x18\x13 \x01(\x0b\x32(.yandex.cloud.compute.v1.MetadataOptions\x12G\n\x0e\x62oot_disk_spec\x18\t \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\x12P\n\x14secondary_disk_specs\x18\n \x03(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x07\x82\xc8\x31\x03<=3\x12H\n\x10local_disk_specs\x18\x12 \x03(\x0b\x32..yandex.cloud.compute.v1.AttachedLocalDiskSpec\x12I\n\x10\x66ilesystem_specs\x18\x11 \x03(\x0b\x32/.yandex.cloud.compute.v1.AttachedFilesystemSpec\x12T\n\x17network_interface_specs\x18\x0b \x03(\x0b\x32-.yandex.cloud.compute.v1.NetworkInterfaceSpecB\x04\xe8\xc7\x31\x01\x12\x36\n\x08hostname\x18\x0c \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x44\n\x11scheduling_policy\x18\r \x01(\x0b\x32).yandex.cloud.compute.v1.SchedulingPolicy\x12\x1a\n\x12service_account_id\x18\x0e \x01(\t\x12\x42\n\x10network_settings\x18\x0f \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x42\n\x10placement_policy\x18\x10 \x01(\x0b\x32(.yandex.cloud.compute.v1.PlacementPolicy\x12:\n\x0cgpu_settings\x18\x14 \x01(\x0b\x32$.yandex.cloud.compute.v1.GpuSettings\x12\x46\n\x12maintenance_policy\x18\x15 \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12G\n\x18maintenance_grace_period\x18\x16 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31s-24h\x12I\n\x14serial_port_settings\x18\x17 \x01(\x0b\x32+.yandex.cloud.compute.v1.SerialPortSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x16\x43reateInstanceMetadata\x12\x1d\n\x0binstance_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xe0\x08\n\x15UpdateInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x13\n\x0bplatform_id\x18\x06 \x01(\t\x12>\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpec\x12N\n\x08metadata\x18\x08 \x03(\x0b\x32<.yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry\x12\x42\n\x10metadata_options\x18\r \x01(\x0b\x32(.yandex.cloud.compute.v1.MetadataOptions\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x42\n\x10network_settings\x18\n \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x42\n\x10placement_policy\x18\x0b \x01(\x0b\x32(.yandex.cloud.compute.v1.PlacementPolicy\x12\x44\n\x11scheduling_policy\x18\x0c \x01(\x0b\x32).yandex.cloud.compute.v1.SchedulingPolicy\x12\x46\n\x12maintenance_policy\x18\x0e \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12G\n\x18maintenance_grace_period\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31s-24h\x12I\n\x14serial_port_settings\x18\x10 \x01(\x0b\x32+.yandex.cloud.compute.v1.SerialPortSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\xc7\x01\n\x1dUpdateInstanceMetadataRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x03(\t\x12R\n\x06upsert\x18\x03 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.UpsertEntry\x1a-\n\x0bUpsertEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x1eUpdateInstanceMetadataMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"b\n\"GetInstanceSerialPortOutputRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x04port\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31,2,3,4\"7\n#GetInstanceSerialPortOutputResponse\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\"8\n\x13StopInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x14StopInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"9\n\x14StartInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\",\n\x15StartInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\";\n\x16RestartInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\".\n\x17RestartInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\x8b\x01\n\x19\x41ttachInstanceDiskRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x12\x61ttached_disk_spec\x18\x02 \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\"B\n\x1a\x41ttachInstanceDiskMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64isk_id\x18\x02 \x01(\t\"\x9a\x01\n\x19\x44\x65tachInstanceDiskRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\x07\x64isk_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12/\n\x0b\x64\x65vice_name\x18\x03 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}H\x00\x42\x0c\n\x04\x64isk\x12\x04\xc0\xc1\x31\x01\"B\n\x1a\x44\x65tachInstanceDiskMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64isk_id\x18\x02 \x01(\t\"\x9d\x01\n\x1f\x41ttachInstanceFilesystemRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x18\x61ttached_filesystem_spec\x18\x02 \x01(\x0b\x32/.yandex.cloud.compute.v1.AttachedFilesystemSpecB\x04\xe8\xc7\x31\x01\"N\n AttachInstanceFilesystemMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x15\n\rfilesystem_id\x18\x02 \x01(\t\"\xac\x01\n\x1f\x44\x65tachInstanceFilesystemRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\rfilesystem_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12/\n\x0b\x64\x65vice_name\x18\x03 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}H\x00\x42\x12\n\nfilesystem\x12\x04\xc0\xc1\x31\x01\"N\n DetachInstanceFilesystemMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x15\n\rfilesystem_id\x18\x02 \x01(\t\"\xf8\x01\n%AttachInstanceNetworkInterfaceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x17network_interface_index\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tsubnet_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12L\n\x17primary_v4_address_spec\x18\x04 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12 \n\x12security_group_ids\x18\x06 \x03(\tB\x04\xe8\xc7\x31\x01J\x04\x08\x05\x10\x06\"^\n&AttachInstanceNetworkInterfaceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\"i\n%DetachInstanceNetworkInterfaceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x17network_interface_index\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"^\n&DetachInstanceNetworkInterfaceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\"\xb6\x01\n\x1d\x41\x64\x64InstanceOneToOneNatRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\x12\x18\n\x10internal_address\x18\x03 \x01(\t\x12\x45\n\x13one_to_one_nat_spec\x18\x04 \x01(\x0b\x32(.yandex.cloud.compute.v1.OneToOneNatSpec\"5\n\x1e\x41\x64\x64InstanceOneToOneNatMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"r\n RemoveInstanceOneToOneNatRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\x12\x18\n\x10internal_address\x18\x03 \x01(\t\"8\n!RemoveInstanceOneToOneNatMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\xe5\x02\n%UpdateInstanceNetworkInterfaceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x17network_interface_index\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\x12L\n\x17primary_v4_address_spec\x18\x05 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12L\n\x17primary_v6_address_spec\x18\x06 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\"^\n&UpdateInstanceNetworkInterfaceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\"L\n\'SimulateInstanceMaintenanceEventRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"?\n(SimulateInstanceMaintenanceEventMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\x80\x01\n\x1dListInstanceOperationsRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"p\n\x1eListInstanceOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe7\x01\n\rResourcesSpec\x12&\n\x06memory\x18\x01 \x01(\x03\x42\x16\xe8\xc7\x31\x01\xfa\xc7\x31\x0e<=274877906944\x12i\n\x05\x63ores\x18\x02 \x01(\x03\x42Z\xe8\xc7\x31\x01\xfa\xc7\x31R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80\x12(\n\rcore_fraction\x18\x03 \x01(\x03\x42\x11\xfa\xc7\x31\r0,5,20,50,100\x12\x19\n\x04gpus\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30,1,2,4\"\xb6\x05\n\x10\x41ttachedDiskSpec\x12<\n\x04mode\x18\x01 \x01(\x0e\x32..yandex.cloud.compute.v1.AttachedDiskSpec.Mode\x12-\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}\x12\x13\n\x0b\x61uto_delete\x18\x03 \x01(\x08\x12G\n\tdisk_spec\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpecH\x00\x12\x1b\n\x07\x64isk_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x1a\xee\x02\n\x08\x44iskSpec\x12\x32\n\x04name\x18\x01 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x19\n\x07type_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12+\n\x04size\x18\x04 \x01(\x03\x42\x1d\xe8\xc7\x31\x01\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12\x1c\n\x08image_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12K\n\x15\x64isk_placement_policy\x18\x07 \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x12\x12\n\nblock_size\x18\x08 \x01(\x03\x12\x1c\n\nkms_key_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50B\x08\n\x06source\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x42\x0c\n\x04\x64isk\x12\x04\xc0\xc1\x31\x01\"+\n\x15\x41ttachedLocalDiskSpec\x12\x12\n\x04size\x18\x01 \x01(\x03\x42\x04\xe8\xc7\x31\x01\"\xe9\x01\n\x16\x41ttachedFilesystemSpec\x12\x42\n\x04mode\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.compute.v1.AttachedFilesystemSpec.Mode\x12-\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}\x12\x1f\n\rfilesystem_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"\x84\x02\n\x14NetworkInterfaceSpec\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x17primary_v4_address_spec\x18\x02 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12L\n\x17primary_v6_address_spec\x18\x03 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12\x1a\n\x12security_group_ids\x18\x06 \x03(\t\x12\r\n\x05index\x18\x07 \x01(\tJ\x04\x08\x04\x10\x06\"\xae\x01\n\x12PrimaryAddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x45\n\x13one_to_one_nat_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.compute.v1.OneToOneNatSpec\x12@\n\x10\x64ns_record_specs\x18\x03 \x03(\x0b\x32&.yandex.cloud.compute.v1.DnsRecordSpec\"\x9c\x01\n\x0fOneToOneNatSpec\x12\x36\n\nip_version\x18\x01 \x01(\x0e\x32\".yandex.cloud.compute.v1.IpVersion\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12@\n\x10\x64ns_record_specs\x18\x03 \x03(\x0b\x32&.yandex.cloud.compute.v1.DnsRecordSpec\"_\n\rDnsRecordSpec\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"e\n\x13MoveInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"d\n\x14MoveInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"\xe4\x02\n\x17RelocateInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x64\x65stination_zone_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12Y\n\x17network_interface_specs\x18\x03 \x03(\x0b\x32-.yandex.cloud.compute.v1.NetworkInterfaceSpecB\t\xe8\xc7\x31\x01\x82\xc8\x31\x01\x31\x12I\n\x13\x62oot_disk_placement\x18\x04 \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x12U\n\x19secondary_disk_placements\x18\x05 \x03(\x0b\x32\x32.yandex.cloud.compute.v1.DiskPlacementPolicyChange\"d\n\x18RelocateInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x16\n\x0esource_zone_id\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65stination_zone_id\x18\x03 \x01(\t\"0\n\x19GuestStopInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\".\n\x17PreemptInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\",\n\x15\x43rashInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t*#\n\x0cInstanceView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\x9f*\n\x0fInstanceService\x12\x82\x01\n\x03Get\x12+.yandex.cloud.compute.v1.GetInstanceRequest\x1a!.yandex.cloud.compute.v1.Instance\"+\x82\xd3\xe4\x93\x02%\x12#/compute/v1/instances/{instance_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.compute.v1.ListInstancesRequest\x1a..yandex.cloud.compute.v1.ListInstancesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/compute/v1/instances\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.compute.v1.CreateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*\"\n\x16\x43reateInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x1a\"\x15/compute/v1/instances:\x01*\x12\xb1\x01\n\x06Update\x12..yandex.cloud.compute.v1.UpdateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*\"\n\x16UpdateInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02(2#/compute/v1/instances/{instance_id}:\x01*\x12\xbb\x01\n\x06\x44\x65lete\x12..yandex.cloud.compute.v1.DeleteInstanceRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*/\n\x16\x44\x65leteInstanceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/compute/v1/instances/{instance_id}\x12\xd8\x01\n\x0eUpdateMetadata\x12\x36.yandex.cloud.compute.v1.UpdateInstanceMetadataRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2**\n\x1eUpdateInstanceMetadataMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x37\"2/compute/v1/instances/{instance_id}/updateMetadata:\x01*\x12\xce\x01\n\x13GetSerialPortOutput\x12;.yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest\x1a<.yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/compute/v1/instances/{instance_id}:serialPortOutput\x12\xba\x01\n\x04Stop\x12,.yandex.cloud.compute.v1.StopInstanceRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*-\n\x14StopInstanceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02*\"(/compute/v1/instances/{instance_id}:stop\x12\xb1\x01\n\x05Start\x12-.yandex.cloud.compute.v1.StartInstanceRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*!\n\x15StartInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02+\")/compute/v1/instances/{instance_id}:start\x12\xc6\x01\n\x07Restart\x12/.yandex.cloud.compute.v1.RestartInstanceRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*0\n\x17RestartInstanceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02-\"+/compute/v1/instances/{instance_id}:restart\x12\xc8\x01\n\nAttachDisk\x12\x32.yandex.cloud.compute.v1.AttachInstanceDiskRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*&\n\x1a\x41ttachInstanceDiskMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x33\"./compute/v1/instances/{instance_id}:attachDisk:\x01*\x12\xc8\x01\n\nDetachDisk\x12\x32.yandex.cloud.compute.v1.DetachInstanceDiskRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*&\n\x1a\x44\x65tachInstanceDiskMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x33\"./compute/v1/instances/{instance_id}:detachDisk:\x01*\x12\xe0\x01\n\x10\x41ttachFilesystem\x12\x38.yandex.cloud.compute.v1.AttachInstanceFilesystemRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*,\n AttachInstanceFilesystemMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x39\"4/compute/v1/instances/{instance_id}:attachFilesystem:\x01*\x12\xe0\x01\n\x10\x44\x65tachFilesystem\x12\x38.yandex.cloud.compute.v1.DetachInstanceFilesystemRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*,\n DetachInstanceFilesystemMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x39\"4/compute/v1/instances/{instance_id}:detachFilesystem:\x01*\x12\xf8\x01\n\x16\x41ttachNetworkInterface\x12>.yandex.cloud.compute.v1.AttachInstanceNetworkInterfaceRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*2\n&AttachInstanceNetworkInterfaceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02?\":/compute/v1/instances/{instance_id}:attachNetworkInterface:\x01*\x12\xf8\x01\n\x16\x44\x65tachNetworkInterface\x12>.yandex.cloud.compute.v1.DetachInstanceNetworkInterfaceRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*2\n&DetachInstanceNetworkInterfaceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02?\":/compute/v1/instances/{instance_id}:detachNetworkInterface:\x01*\x12\xd8\x01\n\x0e\x41\x64\x64OneToOneNat\x12\x36.yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2**\n\x1e\x41\x64\x64InstanceOneToOneNatMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x37\"2/compute/v1/instances/{instance_id}/addOneToOneNat:\x01*\x12\xe4\x01\n\x11RemoveOneToOneNat\x12\x39.yandex.cloud.compute.v1.RemoveInstanceOneToOneNatRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*-\n!RemoveInstanceOneToOneNatMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02:\"5/compute/v1/instances/{instance_id}/removeOneToOneNat:\x01*\x12\xf8\x01\n\x16UpdateNetworkInterface\x12>.yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*2\n&UpdateInstanceNetworkInterfaceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02?2:/compute/v1/instances/{instance_id}/updateNetworkInterface:\x01*\x12\xb9\x01\n\x0eListOperations\x12\x36.yandex.cloud.compute.v1.ListInstanceOperationsRequest\x1a\x37.yandex.cloud.compute.v1.ListInstanceOperationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./compute/v1/instances/{instance_id}/operations\x12\xb0\x01\n\x04Move\x12,.yandex.cloud.compute.v1.MoveInstanceRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2* \n\x14MoveInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02-\"(/compute/v1/instances/{instance_id}:move:\x01*\x12\xc0\x01\n\x08Relocate\x12\x30.yandex.cloud.compute.v1.RelocateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*$\n\x18RelocateInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x31\",/compute/v1/instances/{instance_id}:relocate:\x01*\x12\x8e\x02\n\x18SimulateMaintenanceEvent\x12@.yandex.cloud.compute.v1.SimulateInstanceMaintenanceEventRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*A\n(SimulateInstanceMaintenanceEventMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x41\"</compute/v1/instances/{instance_id}:simulateMaintenanceEvent:\x01*\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/compute/v1/instances/{resource_id}:listAccessBindings\x12\xf4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02:\"5/compute/v1/instances/{resource_id}:setAccessBindings:\x01*\x12\x80\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02=\"8/compute/v1/instances/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.instance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _GETINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _GETINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTINSTANCESREQUEST.fields_by_name['folder_id']._options = None
  _LISTINSTANCESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTINSTANCESREQUEST.fields_by_name['page_size']._options = None
  _LISTINSTANCESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTINSTANCESREQUEST.fields_by_name['page_token']._options = None
  _LISTINSTANCESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTINSTANCESREQUEST.fields_by_name['filter']._options = None
  _LISTINSTANCESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTINSTANCESREQUEST.fields_by_name['order_by']._options = None
  _LISTINSTANCESREQUEST.fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _CREATEINSTANCEREQUEST_LABELSENTRY._options = None
  _CREATEINSTANCEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEINSTANCEREQUEST_METADATAENTRY._options = None
  _CREATEINSTANCEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _CREATEINSTANCEREQUEST.fields_by_name['folder_id']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEINSTANCEREQUEST.fields_by_name['name']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEINSTANCEREQUEST.fields_by_name['description']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEINSTANCEREQUEST.fields_by_name['labels']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEINSTANCEREQUEST.fields_by_name['zone_id']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEINSTANCEREQUEST.fields_by_name['platform_id']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['platform_id']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEREQUEST.fields_by_name['resources_spec']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['resources_spec']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEREQUEST.fields_by_name['boot_disk_spec']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['boot_disk_spec']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEREQUEST.fields_by_name['secondary_disk_specs']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['secondary_disk_specs']._serialized_options = b'\202\3101\003<=3'
  _CREATEINSTANCEREQUEST.fields_by_name['network_interface_specs']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['network_interface_specs']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEREQUEST.fields_by_name['hostname']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['hostname']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEINSTANCEREQUEST.fields_by_name['maintenance_grace_period']._options = None
  _CREATEINSTANCEREQUEST.fields_by_name['maintenance_grace_period']._serialized_options = b'\372\3071\0061s-24h'
  _CREATEINSTANCEMETADATA.fields_by_name['instance_id']._options = None
  _CREATEINSTANCEMETADATA.fields_by_name['instance_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATEINSTANCEREQUEST_LABELSENTRY._options = None
  _UPDATEINSTANCEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEINSTANCEREQUEST_METADATAENTRY._options = None
  _UPDATEINSTANCEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _UPDATEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _UPDATEINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEINSTANCEREQUEST.fields_by_name['name']._options = None
  _UPDATEINSTANCEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEINSTANCEREQUEST.fields_by_name['description']._options = None
  _UPDATEINSTANCEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEINSTANCEREQUEST.fields_by_name['labels']._options = None
  _UPDATEINSTANCEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATEINSTANCEREQUEST.fields_by_name['maintenance_grace_period']._options = None
  _UPDATEINSTANCEREQUEST.fields_by_name['maintenance_grace_period']._serialized_options = b'\372\3071\0061s-24h'
  _DELETEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _DELETEINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY._options = None
  _UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY._serialized_options = b'8\001'
  _GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['instance_id']._options = None
  _GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['port']._options = None
  _GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['port']._serialized_options = b'\372\3071\0071,2,3,4'
  _STOPINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _STOPINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _STARTINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTARTINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _RESTARTINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ATTACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._options = None
  _ATTACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ATTACHINSTANCEDISKREQUEST.fields_by_name['attached_disk_spec']._options = None
  _ATTACHINSTANCEDISKREQUEST.fields_by_name['attached_disk_spec']._serialized_options = b'\350\3071\001'
  _DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']._options = None
  _DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']._serialized_options = b'\300\3011\001'
  _DETACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._options = None
  _DETACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id']._options = None
  _DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id']._serialized_options = b'\212\3101\004<=50'
  _DETACHINSTANCEDISKREQUEST.fields_by_name['device_name']._options = None
  _DETACHINSTANCEDISKREQUEST.fields_by_name['device_name']._serialized_options = b'\362\3071\024[a-z][a-z0-9-_]{,19}'
  _ATTACHINSTANCEFILESYSTEMREQUEST.fields_by_name['instance_id']._options = None
  _ATTACHINSTANCEFILESYSTEMREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ATTACHINSTANCEFILESYSTEMREQUEST.fields_by_name['attached_filesystem_spec']._options = None
  _ATTACHINSTANCEFILESYSTEMREQUEST.fields_by_name['attached_filesystem_spec']._serialized_options = b'\350\3071\001'
  _DETACHINSTANCEFILESYSTEMREQUEST.oneofs_by_name['filesystem']._options = None
  _DETACHINSTANCEFILESYSTEMREQUEST.oneofs_by_name['filesystem']._serialized_options = b'\300\3011\001'
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['instance_id']._options = None
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['filesystem_id']._options = None
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['filesystem_id']._serialized_options = b'\212\3101\004<=50'
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['device_name']._options = None
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['device_name']._serialized_options = b'\362\3071\024[a-z][a-z0-9-_]{,19}'
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['instance_id']._options = None
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['network_interface_index']._options = None
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['network_interface_index']._serialized_options = b'\350\3071\001'
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['subnet_id']._options = None
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001'
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['security_group_ids']._options = None
  _ATTACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['security_group_ids']._serialized_options = b'\350\3071\001'
  _DETACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['instance_id']._options = None
  _DETACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _DETACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['network_interface_index']._options = None
  _DETACHINSTANCENETWORKINTERFACEREQUEST.fields_by_name['network_interface_index']._serialized_options = b'\350\3071\001'
  _UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['instance_id']._options = None
  _UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['network_interface_index']._options = None
  _UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['network_interface_index']._serialized_options = b'\350\3071\001'
  _SIMULATEINSTANCEMAINTENANCEEVENTREQUEST.fields_by_name['instance_id']._options = None
  _SIMULATEINSTANCEMAINTENANCEEVENTREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTINSTANCEOPERATIONSREQUEST.fields_by_name['instance_id']._options = None
  _LISTINSTANCEOPERATIONSREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _RESOURCESSPEC.fields_by_name['memory']._options = None
  _RESOURCESSPEC.fields_by_name['memory']._serialized_options = b'\350\3071\001\372\3071\016<=274877906944'
  _RESOURCESSPEC.fields_by_name['cores']._options = None
  _RESOURCESSPEC.fields_by_name['cores']._serialized_options = b'\350\3071\001\372\3071R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80'
  _RESOURCESSPEC.fields_by_name['core_fraction']._options = None
  _RESOURCESSPEC.fields_by_name['core_fraction']._serialized_options = b'\372\3071\r0,5,20,50,100'
  _RESOURCESSPEC.fields_by_name['gpus']._options = None
  _RESOURCESSPEC.fields_by_name['gpus']._serialized_options = b'\372\3071\0070,1,2,4'
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['name']._options = None
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['description']._options = None
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['type_id']._options = None
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['type_id']._serialized_options = b'\212\3101\004<=50'
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['size']._options = None
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['size']._serialized_options = b'\350\3071\001\372\3071\0254194304-4398046511104'
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id']._options = None
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id']._options = None
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id']._serialized_options = b'\212\3101\004<=50'
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['kms_key_id']._options = None
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['kms_key_id']._serialized_options = b'\212\3101\004<=50'
  _ATTACHEDDISKSPEC.oneofs_by_name['disk']._options = None
  _ATTACHEDDISKSPEC.oneofs_by_name['disk']._serialized_options = b'\300\3011\001'
  _ATTACHEDDISKSPEC.fields_by_name['device_name']._options = None
  _ATTACHEDDISKSPEC.fields_by_name['device_name']._serialized_options = b'\362\3071\024[a-z][a-z0-9-_]{,19}'
  _ATTACHEDDISKSPEC.fields_by_name['disk_id']._options = None
  _ATTACHEDDISKSPEC.fields_by_name['disk_id']._serialized_options = b'\212\3101\004<=50'
  _ATTACHEDLOCALDISKSPEC.fields_by_name['size']._options = None
  _ATTACHEDLOCALDISKSPEC.fields_by_name['size']._serialized_options = b'\350\3071\001'
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._options = None
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._serialized_options = b'\362\3071\024[a-z][a-z0-9-_]{,19}'
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['filesystem_id']._options = None
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['filesystem_id']._serialized_options = b'\212\3101\004<=50'
  _NETWORKINTERFACESPEC.fields_by_name['subnet_id']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DNSRECORDSPEC.fields_by_name['fqdn']._options = None
  _DNSRECORDSPEC.fields_by_name['fqdn']._serialized_options = b'\350\3071\001'
  _DNSRECORDSPEC.fields_by_name['ttl']._options = None
  _DNSRECORDSPEC.fields_by_name['ttl']._serialized_options = b'\372\3071\0070-86400'
  _MOVEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _MOVEINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEINSTANCEREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVEINSTANCEREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RELOCATEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _RELOCATEINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RELOCATEINSTANCEREQUEST.fields_by_name['destination_zone_id']._options = None
  _RELOCATEINSTANCEREQUEST.fields_by_name['destination_zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RELOCATEINSTANCEREQUEST.fields_by_name['network_interface_specs']._options = None
  _RELOCATEINSTANCEREQUEST.fields_by_name['network_interface_specs']._serialized_options = b'\350\3071\001\202\3101\0011'
  _INSTANCESERVICE.methods_by_name['Get']._options = None
  _INSTANCESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/compute/v1/instances/{instance_id}'
  _INSTANCESERVICE.methods_by_name['List']._options = None
  _INSTANCESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/compute/v1/instances'
  _INSTANCESERVICE.methods_by_name['Create']._options = None
  _INSTANCESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateInstanceMetadata\022\010Instance\202\323\344\223\002\032\"\025/compute/v1/instances:\001*'
  _INSTANCESERVICE.methods_by_name['Update']._options = None
  _INSTANCESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateInstanceMetadata\022\010Instance\202\323\344\223\002(2#/compute/v1/instances/{instance_id}:\001*'
  _INSTANCESERVICE.methods_by_name['Delete']._options = None
  _INSTANCESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteInstanceMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/compute/v1/instances/{instance_id}'
  _INSTANCESERVICE.methods_by_name['UpdateMetadata']._options = None
  _INSTANCESERVICE.methods_by_name['UpdateMetadata']._serialized_options = b'\262\322**\n\036UpdateInstanceMetadataMetadata\022\010Instance\202\323\344\223\0027\"2/compute/v1/instances/{instance_id}/updateMetadata:\001*'
  _INSTANCESERVICE.methods_by_name['GetSerialPortOutput']._options = None
  _INSTANCESERVICE.methods_by_name['GetSerialPortOutput']._serialized_options = b'\202\323\344\223\0026\0224/compute/v1/instances/{instance_id}:serialPortOutput'
  _INSTANCESERVICE.methods_by_name['Stop']._options = None
  _INSTANCESERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*-\n\024StopInstanceMetadata\022\025google.protobuf.Empty\202\323\344\223\002*\"(/compute/v1/instances/{instance_id}:stop'
  _INSTANCESERVICE.methods_by_name['Start']._options = None
  _INSTANCESERVICE.methods_by_name['Start']._serialized_options = b'\262\322*!\n\025StartInstanceMetadata\022\010Instance\202\323\344\223\002+\")/compute/v1/instances/{instance_id}:start'
  _INSTANCESERVICE.methods_by_name['Restart']._options = None
  _INSTANCESERVICE.methods_by_name['Restart']._serialized_options = b'\262\322*0\n\027RestartInstanceMetadata\022\025google.protobuf.Empty\202\323\344\223\002-\"+/compute/v1/instances/{instance_id}:restart'
  _INSTANCESERVICE.methods_by_name['AttachDisk']._options = None
  _INSTANCESERVICE.methods_by_name['AttachDisk']._serialized_options = b'\262\322*&\n\032AttachInstanceDiskMetadata\022\010Instance\202\323\344\223\0023\"./compute/v1/instances/{instance_id}:attachDisk:\001*'
  _INSTANCESERVICE.methods_by_name['DetachDisk']._options = None
  _INSTANCESERVICE.methods_by_name['DetachDisk']._serialized_options = b'\262\322*&\n\032DetachInstanceDiskMetadata\022\010Instance\202\323\344\223\0023\"./compute/v1/instances/{instance_id}:detachDisk:\001*'
  _INSTANCESERVICE.methods_by_name['AttachFilesystem']._options = None
  _INSTANCESERVICE.methods_by_name['AttachFilesystem']._serialized_options = b'\262\322*,\n AttachInstanceFilesystemMetadata\022\010Instance\202\323\344\223\0029\"4/compute/v1/instances/{instance_id}:attachFilesystem:\001*'
  _INSTANCESERVICE.methods_by_name['DetachFilesystem']._options = None
  _INSTANCESERVICE.methods_by_name['DetachFilesystem']._serialized_options = b'\262\322*,\n DetachInstanceFilesystemMetadata\022\010Instance\202\323\344\223\0029\"4/compute/v1/instances/{instance_id}:detachFilesystem:\001*'
  _INSTANCESERVICE.methods_by_name['AttachNetworkInterface']._options = None
  _INSTANCESERVICE.methods_by_name['AttachNetworkInterface']._serialized_options = b'\262\322*2\n&AttachInstanceNetworkInterfaceMetadata\022\010Instance\202\323\344\223\002?\":/compute/v1/instances/{instance_id}:attachNetworkInterface:\001*'
  _INSTANCESERVICE.methods_by_name['DetachNetworkInterface']._options = None
  _INSTANCESERVICE.methods_by_name['DetachNetworkInterface']._serialized_options = b'\262\322*2\n&DetachInstanceNetworkInterfaceMetadata\022\010Instance\202\323\344\223\002?\":/compute/v1/instances/{instance_id}:detachNetworkInterface:\001*'
  _INSTANCESERVICE.methods_by_name['AddOneToOneNat']._options = None
  _INSTANCESERVICE.methods_by_name['AddOneToOneNat']._serialized_options = b'\262\322**\n\036AddInstanceOneToOneNatMetadata\022\010Instance\202\323\344\223\0027\"2/compute/v1/instances/{instance_id}/addOneToOneNat:\001*'
  _INSTANCESERVICE.methods_by_name['RemoveOneToOneNat']._options = None
  _INSTANCESERVICE.methods_by_name['RemoveOneToOneNat']._serialized_options = b'\262\322*-\n!RemoveInstanceOneToOneNatMetadata\022\010Instance\202\323\344\223\002:\"5/compute/v1/instances/{instance_id}/removeOneToOneNat:\001*'
  _INSTANCESERVICE.methods_by_name['UpdateNetworkInterface']._options = None
  _INSTANCESERVICE.methods_by_name['UpdateNetworkInterface']._serialized_options = b'\262\322*2\n&UpdateInstanceNetworkInterfaceMetadata\022\010Instance\202\323\344\223\002?2:/compute/v1/instances/{instance_id}/updateNetworkInterface:\001*'
  _INSTANCESERVICE.methods_by_name['ListOperations']._options = None
  _INSTANCESERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0020\022./compute/v1/instances/{instance_id}/operations'
  _INSTANCESERVICE.methods_by_name['Move']._options = None
  _INSTANCESERVICE.methods_by_name['Move']._serialized_options = b'\262\322* \n\024MoveInstanceMetadata\022\010Instance\202\323\344\223\002-\"(/compute/v1/instances/{instance_id}:move:\001*'
  _INSTANCESERVICE.methods_by_name['Relocate']._options = None
  _INSTANCESERVICE.methods_by_name['Relocate']._serialized_options = b'\262\322*$\n\030RelocateInstanceMetadata\022\010Instance\202\323\344\223\0021\",/compute/v1/instances/{instance_id}:relocate:\001*'
  _INSTANCESERVICE.methods_by_name['SimulateMaintenanceEvent']._options = None
  _INSTANCESERVICE.methods_by_name['SimulateMaintenanceEvent']._serialized_options = b'\262\322*A\n(SimulateInstanceMaintenanceEventMetadata\022\025google.protobuf.Empty\202\323\344\223\002A\"</compute/v1/instances/{instance_id}:simulateMaintenanceEvent:\001*'
  _INSTANCESERVICE.methods_by_name['ListAccessBindings']._options = None
  _INSTANCESERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0028\0226/compute/v1/instances/{resource_id}:listAccessBindings'
  _INSTANCESERVICE.methods_by_name['SetAccessBindings']._options = None
  _INSTANCESERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002:\"5/compute/v1/instances/{resource_id}:setAccessBindings:\001*'
  _INSTANCESERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _INSTANCESERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002=\"8/compute/v1/instances/{resource_id}:updateAccessBindings:\001*'
  _globals['_INSTANCEVIEW']._serialized_start=9962
  _globals['_INSTANCEVIEW']._serialized_end=9997
  _globals['_GETINSTANCEREQUEST']._serialized_start=429
  _globals['_GETINSTANCEREQUEST']._serialized_end=537
  _globals['_LISTINSTANCESREQUEST']._serialized_start=540
  _globals['_LISTINSTANCESREQUEST']._serialized_end=714
  _globals['_LISTINSTANCESRESPONSE']._serialized_start=716
  _globals['_LISTINSTANCESRESPONSE']._serialized_end=818
  _globals['_CREATEINSTANCEREQUEST']._serialized_start=821
  _globals['_CREATEINSTANCEREQUEST']._serialized_end=2439
  _globals['_CREATEINSTANCEREQUEST_LABELSENTRY']._serialized_start=2345
  _globals['_CREATEINSTANCEREQUEST_LABELSENTRY']._serialized_end=2390
  _globals['_CREATEINSTANCEREQUEST_METADATAENTRY']._serialized_start=2392
  _globals['_CREATEINSTANCEREQUEST_METADATAENTRY']._serialized_end=2439
  _globals['_CREATEINSTANCEMETADATA']._serialized_start=2441
  _globals['_CREATEINSTANCEMETADATA']._serialized_end=2496
  _globals['_UPDATEINSTANCEREQUEST']._serialized_start=2499
  _globals['_UPDATEINSTANCEREQUEST']._serialized_end=3619
  _globals['_UPDATEINSTANCEREQUEST_LABELSENTRY']._serialized_start=2345
  _globals['_UPDATEINSTANCEREQUEST_LABELSENTRY']._serialized_end=2390
  _globals['_UPDATEINSTANCEREQUEST_METADATAENTRY']._serialized_start=2392
  _globals['_UPDATEINSTANCEREQUEST_METADATAENTRY']._serialized_end=2439
  _globals['_UPDATEINSTANCEMETADATA']._serialized_start=3621
  _globals['_UPDATEINSTANCEMETADATA']._serialized_end=3666
  _globals['_DELETEINSTANCEREQUEST']._serialized_start=3668
  _globals['_DELETEINSTANCEREQUEST']._serialized_end=3726
  _globals['_DELETEINSTANCEMETADATA']._serialized_start=3728
  _globals['_DELETEINSTANCEMETADATA']._serialized_end=3773
  _globals['_UPDATEINSTANCEMETADATAREQUEST']._serialized_start=3776
  _globals['_UPDATEINSTANCEMETADATAREQUEST']._serialized_end=3975
  _globals['_UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY']._serialized_start=3930
  _globals['_UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY']._serialized_end=3975
  _globals['_UPDATEINSTANCEMETADATAMETADATA']._serialized_start=3977
  _globals['_UPDATEINSTANCEMETADATAMETADATA']._serialized_end=4030
  _globals['_GETINSTANCESERIALPORTOUTPUTREQUEST']._serialized_start=4032
  _globals['_GETINSTANCESERIALPORTOUTPUTREQUEST']._serialized_end=4130
  _globals['_GETINSTANCESERIALPORTOUTPUTRESPONSE']._serialized_start=4132
  _globals['_GETINSTANCESERIALPORTOUTPUTRESPONSE']._serialized_end=4187
  _globals['_STOPINSTANCEREQUEST']._serialized_start=4189
  _globals['_STOPINSTANCEREQUEST']._serialized_end=4245
  _globals['_STOPINSTANCEMETADATA']._serialized_start=4247
  _globals['_STOPINSTANCEMETADATA']._serialized_end=4290
  _globals['_STARTINSTANCEREQUEST']._serialized_start=4292
  _globals['_STARTINSTANCEREQUEST']._serialized_end=4349
  _globals['_STARTINSTANCEMETADATA']._serialized_start=4351
  _globals['_STARTINSTANCEMETADATA']._serialized_end=4395
  _globals['_RESTARTINSTANCEREQUEST']._serialized_start=4397
  _globals['_RESTARTINSTANCEREQUEST']._serialized_end=4456
  _globals['_RESTARTINSTANCEMETADATA']._serialized_start=4458
  _globals['_RESTARTINSTANCEMETADATA']._serialized_end=4504
  _globals['_ATTACHINSTANCEDISKREQUEST']._serialized_start=4507
  _globals['_ATTACHINSTANCEDISKREQUEST']._serialized_end=4646
  _globals['_ATTACHINSTANCEDISKMETADATA']._serialized_start=4648
  _globals['_ATTACHINSTANCEDISKMETADATA']._serialized_end=4714
  _globals['_DETACHINSTANCEDISKREQUEST']._serialized_start=4717
  _globals['_DETACHINSTANCEDISKREQUEST']._serialized_end=4871
  _globals['_DETACHINSTANCEDISKMETADATA']._serialized_start=4873
  _globals['_DETACHINSTANCEDISKMETADATA']._serialized_end=4939
  _globals['_ATTACHINSTANCEFILESYSTEMREQUEST']._serialized_start=4942
  _globals['_ATTACHINSTANCEFILESYSTEMREQUEST']._serialized_end=5099
  _globals['_ATTACHINSTANCEFILESYSTEMMETADATA']._serialized_start=5101
  _globals['_ATTACHINSTANCEFILESYSTEMMETADATA']._serialized_end=5179
  _globals['_DETACHINSTANCEFILESYSTEMREQUEST']._serialized_start=5182
  _globals['_DETACHINSTANCEFILESYSTEMREQUEST']._serialized_end=5354
  _globals['_DETACHINSTANCEFILESYSTEMMETADATA']._serialized_start=5356
  _globals['_DETACHINSTANCEFILESYSTEMMETADATA']._serialized_end=5434
  _globals['_ATTACHINSTANCENETWORKINTERFACEREQUEST']._serialized_start=5437
  _globals['_ATTACHINSTANCENETWORKINTERFACEREQUEST']._serialized_end=5685
  _globals['_ATTACHINSTANCENETWORKINTERFACEMETADATA']._serialized_start=5687
  _globals['_ATTACHINSTANCENETWORKINTERFACEMETADATA']._serialized_end=5781
  _globals['_DETACHINSTANCENETWORKINTERFACEREQUEST']._serialized_start=5783
  _globals['_DETACHINSTANCENETWORKINTERFACEREQUEST']._serialized_end=5888
  _globals['_DETACHINSTANCENETWORKINTERFACEMETADATA']._serialized_start=5890
  _globals['_DETACHINSTANCENETWORKINTERFACEMETADATA']._serialized_end=5984
  _globals['_ADDINSTANCEONETOONENATREQUEST']._serialized_start=5987
  _globals['_ADDINSTANCEONETOONENATREQUEST']._serialized_end=6169
  _globals['_ADDINSTANCEONETOONENATMETADATA']._serialized_start=6171
  _globals['_ADDINSTANCEONETOONENATMETADATA']._serialized_end=6224
  _globals['_REMOVEINSTANCEONETOONENATREQUEST']._serialized_start=6226
  _globals['_REMOVEINSTANCEONETOONENATREQUEST']._serialized_end=6340
  _globals['_REMOVEINSTANCEONETOONENATMETADATA']._serialized_start=6342
  _globals['_REMOVEINSTANCEONETOONENATMETADATA']._serialized_end=6398
  _globals['_UPDATEINSTANCENETWORKINTERFACEREQUEST']._serialized_start=6401
  _globals['_UPDATEINSTANCENETWORKINTERFACEREQUEST']._serialized_end=6758
  _globals['_UPDATEINSTANCENETWORKINTERFACEMETADATA']._serialized_start=6760
  _globals['_UPDATEINSTANCENETWORKINTERFACEMETADATA']._serialized_end=6854
  _globals['_SIMULATEINSTANCEMAINTENANCEEVENTREQUEST']._serialized_start=6856
  _globals['_SIMULATEINSTANCEMAINTENANCEEVENTREQUEST']._serialized_end=6932
  _globals['_SIMULATEINSTANCEMAINTENANCEEVENTMETADATA']._serialized_start=6934
  _globals['_SIMULATEINSTANCEMAINTENANCEEVENTMETADATA']._serialized_end=6997
  _globals['_LISTINSTANCEOPERATIONSREQUEST']._serialized_start=7000
  _globals['_LISTINSTANCEOPERATIONSREQUEST']._serialized_end=7128
  _globals['_LISTINSTANCEOPERATIONSRESPONSE']._serialized_start=7130
  _globals['_LISTINSTANCEOPERATIONSRESPONSE']._serialized_end=7242
  _globals['_RESOURCESSPEC']._serialized_start=7245
  _globals['_RESOURCESSPEC']._serialized_end=7476
  _globals['_ATTACHEDDISKSPEC']._serialized_start=7479
  _globals['_ATTACHEDDISKSPEC']._serialized_end=8173
  _globals['_ATTACHEDDISKSPEC_DISKSPEC']._serialized_start=7732
  _globals['_ATTACHEDDISKSPEC_DISKSPEC']._serialized_end=8098
  _globals['_ATTACHEDDISKSPEC_MODE']._serialized_start=8100
  _globals['_ATTACHEDDISKSPEC_MODE']._serialized_end=8159
  _globals['_ATTACHEDLOCALDISKSPEC']._serialized_start=8175
  _globals['_ATTACHEDLOCALDISKSPEC']._serialized_end=8218
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_start=8221
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_end=8454
  _globals['_ATTACHEDFILESYSTEMSPEC_MODE']._serialized_start=8100
  _globals['_ATTACHEDFILESYSTEMSPEC_MODE']._serialized_end=8159
  _globals['_NETWORKINTERFACESPEC']._serialized_start=8457
  _globals['_NETWORKINTERFACESPEC']._serialized_end=8717
  _globals['_PRIMARYADDRESSSPEC']._serialized_start=8720
  _globals['_PRIMARYADDRESSSPEC']._serialized_end=8894
  _globals['_ONETOONENATSPEC']._serialized_start=8897
  _globals['_ONETOONENATSPEC']._serialized_end=9053
  _globals['_DNSRECORDSPEC']._serialized_start=9055
  _globals['_DNSRECORDSPEC']._serialized_end=9150
  _globals['_MOVEINSTANCEREQUEST']._serialized_start=9152
  _globals['_MOVEINSTANCEREQUEST']._serialized_end=9253
  _globals['_MOVEINSTANCEMETADATA']._serialized_start=9255
  _globals['_MOVEINSTANCEMETADATA']._serialized_end=9355
  _globals['_RELOCATEINSTANCEREQUEST']._serialized_start=9358
  _globals['_RELOCATEINSTANCEREQUEST']._serialized_end=9714
  _globals['_RELOCATEINSTANCEMETADATA']._serialized_start=9716
  _globals['_RELOCATEINSTANCEMETADATA']._serialized_end=9816
  _globals['_GUESTSTOPINSTANCEMETADATA']._serialized_start=9818
  _globals['_GUESTSTOPINSTANCEMETADATA']._serialized_end=9866
  _globals['_PREEMPTINSTANCEMETADATA']._serialized_start=9868
  _globals['_PREEMPTINSTANCEMETADATA']._serialized_end=9914
  _globals['_CRASHINSTANCEMETADATA']._serialized_start=9916
  _globals['_CRASHINSTANCEMETADATA']._serialized_end=9960
  _globals['_INSTANCESERVICE']._serialized_start=10000
  _globals['_INSTANCESERVICE']._serialized_end=15407
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.dataset.v1 import dataset_service_pb2 as yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class DatasetServiceStub(object):
    """A set of methods for managing datasets.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Describe = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/Describe',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DescribeDatasetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DescribeDatasetResponse.FromString,
                )
        self.Validate = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/Validate',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ValidateDatasetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/Create',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.CreateDatasetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.CreateDatasetResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/Update',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.UpdateDatasetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.UpdateDatasetResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/Delete',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DeleteDatasetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DeleteDatasetResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/List',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListDatasetsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListDatasetsResponse.FromString,
                )
        self.ListUploadFormats = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/ListUploadFormats',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListUploadFormatsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListUploadFormatsResponse.FromString,
                )
        self.GetUploadDraftUrl = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/GetUploadDraftUrl',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.GetUploadDraftUrlRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.GetUploadDraftUrlResponse.FromString,
                )
        self.StartMultipartUploadDraft = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/StartMultipartUploadDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.StartMultipartUploadDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.StartMultipartUploadDraftResponse.FromString,
                )
        self.FinishMultipartUploadDraft = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/FinishMultipartUploadDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.FinishMultipartUploadDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.FinishMultipartUploadDraftResponse.FromString,
                )
        self.ListTypes = channel.unary_unary(
                '/yandex.cloud.ai.dataset.v1.DatasetService/ListTypes',
                request_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListTypesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListTypesResponse.FromString,
                )


class DatasetServiceServicer(object):
    """A set of methods for managing datasets.
    """

    def Describe(self, request, context):
        """Returns dataset information by dataset id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Validate(self, request, context):
        """Starts dataset validation process.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists datasets in specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUploadFormats(self, request, context):
        """Lists supported upload formats for the specified dataset task type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUploadDraftUrl(self, request, context):
        """Returns an S3 presigned URL for dataset upload.
        This method only applicable if the dataset size does not exceed 5GB.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartMultipartUploadDraft(self, request, context):
        """Returns a list of S3 presigned URLs for multipart upload of dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinishMultipartUploadDraft(self, request, context):
        """Finishes multipart upload of the dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTypes(self, request, context):
        """Returns a list of dataset types
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DatasetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Describe': grpc.unary_unary_rpc_method_handler(
                    servicer.Describe,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DescribeDatasetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DescribeDatasetResponse.SerializeToString,
            ),
            'Validate': grpc.unary_unary_rpc_method_handler(
                    servicer.Validate,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ValidateDatasetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.CreateDatasetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.CreateDatasetResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.UpdateDatasetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.UpdateDatasetResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DeleteDatasetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DeleteDatasetResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListDatasetsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListDatasetsResponse.SerializeToString,
            ),
            'ListUploadFormats': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUploadFormats,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListUploadFormatsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListUploadFormatsResponse.SerializeToString,
            ),
            'GetUploadDraftUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUploadDraftUrl,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.GetUploadDraftUrlRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.GetUploadDraftUrlResponse.SerializeToString,
            ),
            'StartMultipartUploadDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.StartMultipartUploadDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.StartMultipartUploadDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.StartMultipartUploadDraftResponse.SerializeToString,
            ),
            'FinishMultipartUploadDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.FinishMultipartUploadDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.FinishMultipartUploadDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.FinishMultipartUploadDraftResponse.SerializeToString,
            ),
            'ListTypes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTypes,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListTypesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListTypesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.dataset.v1.DatasetService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DatasetService(object):
    """A set of methods for managing datasets.
    """

    @staticmethod
    def Describe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/Describe',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DescribeDatasetRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DescribeDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Validate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/Validate',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ValidateDatasetRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/Create',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.CreateDatasetRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.CreateDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/Update',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.UpdateDatasetRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.UpdateDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/Delete',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DeleteDatasetRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.DeleteDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/List',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListDatasetsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListDatasetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUploadFormats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/ListUploadFormats',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListUploadFormatsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListUploadFormatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUploadDraftUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/GetUploadDraftUrl',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.GetUploadDraftUrlRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.GetUploadDraftUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartMultipartUploadDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/StartMultipartUploadDraft',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.StartMultipartUploadDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.StartMultipartUploadDraftResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinishMultipartUploadDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/FinishMultipartUploadDraft',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.FinishMultipartUploadDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.FinishMultipartUploadDraftResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTypes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.dataset.v1.DatasetService/ListTypes',
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListTypesRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__service__pb2.ListTypesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.gpu_cluster_pb2
import yandex.cloud.compute.v1.instance_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetGpuClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster to return.

    To get a GPU cluster ID, make a [GpuClusterService.List] request.
    """
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id"]) -> None: ...

global___GetGpuClusterRequest = GetGpuClusterRequest

@typing.final
class ListGpuClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list GPU clusters in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListGpuClustersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListGpuClustersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters GPU clusters listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [GpuCluster.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. The value. Must be 3-63 characters long and match the regular expression `^[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-schedule`.
    """
    order_by: builtins.str
    """A sorting expression that sorts GPU clusters listed in the response.

    The expression must specify the field name from [GpuCluster] and `asc`ending or `desc`ending order,
    e.g. `createdAt desc`.

    Default value: `id asc`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGpuClustersRequest = ListGpuClustersRequest

@typing.final
class ListGpuClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListGpuClustersRequest.page_size], use `next_page_token` as the value
    for the [ListGpuClustersRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def gpu_clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.gpu_cluster_pb2.GpuCluster]:
        """List of GPU clusters in the specified folder."""

    def __init__(
        self,
        *,
        gpu_clusters: collections.abc.Iterable[yandex.cloud.compute.v1.gpu_cluster_pb2.GpuCluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_clusters", b"gpu_clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListGpuClustersResponse = ListGpuClustersResponse

@typing.final
class CreateGpuClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    INTERCONNECT_TYPE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a GPU cluster in.

    To get a folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the GPU cluster.

    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the GPU cluster."""
    zone_id: builtins.str
    """ID of the availability zone where the GPU cluster resides.
    To get a list of available zones use the [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    interconnect_type: yandex.cloud.compute.v1.gpu_cluster_pb2.GpuInterconnectType.ValueType
    """Type of interconnect to use for this GPU cluster."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """GPU cluster labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        interconnect_type: yandex.cloud.compute.v1.gpu_cluster_pb2.GpuInterconnectType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "interconnect_type", b"interconnect_type", "labels", b"labels", "name", b"name", "zone_id", b"zone_id"]) -> None: ...

global___CreateGpuClusterRequest = CreateGpuClusterRequest

@typing.final
class CreateGpuClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster that is being created."""
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id"]) -> None: ...

global___CreateGpuClusterMetadata = CreateGpuClusterMetadata

@typing.final
class UpdateGpuClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster to update.

    To get the GPU cluster ID, make a [GpuClusterService.List] request.
    """
    name: builtins.str
    """New name for the GPU cluster.

    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the GPU cluster."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the GPU cluster should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New GPU cluster labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [GpuClusterService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "gpu_cluster_id", b"gpu_cluster_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateGpuClusterRequest = UpdateGpuClusterRequest

@typing.final
class UpdateGpuClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster that is being updated."""
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id"]) -> None: ...

global___UpdateGpuClusterMetadata = UpdateGpuClusterMetadata

@typing.final
class DeleteGpuClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster to delete.

    To get a GPU cluster ID, make a [GpuClusterService.List] request.
    """
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id"]) -> None: ...

global___DeleteGpuClusterRequest = DeleteGpuClusterRequest

@typing.final
class DeleteGpuClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster that is being deleted."""
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id"]) -> None: ...

global___DeleteGpuClusterMetadata = DeleteGpuClusterMetadata

@typing.final
class ListGpuClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster to list operations for.

    To get a GPU cluster ID, make a [GpuClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListGpuClusterOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListGpuClusterOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGpuClusterOperationsRequest = ListGpuClusterOperationsRequest

@typing.final
class ListGpuClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListGpuClusterOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListGpuClusterOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified GPU cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListGpuClusterOperationsResponse = ListGpuClusterOperationsResponse

@typing.final
class ListGpuClusterInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """ID of the GPU cluster to list instances in.

    To get a GPU cluster ID, make a [GpuClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListGpuClusterInstancesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListGpuClusterInstancesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on the [Instance.name] field.
    """
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "gpu_cluster_id", b"gpu_cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListGpuClusterInstancesRequest = ListGpuClusterInstancesRequest

@typing.final
class ListGpuClusterInstancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListGpuClusterInstancesRequest.page_size], use `next_page_token` as the value
    for the [ListGpuClusterInstancesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instance_pb2.Instance]:
        """List of instances in the specified GPU cluster."""

    def __init__(
        self,
        *,
        instances: collections.abc.Iterable[yandex.cloud.compute.v1.instance_pb2.Instance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instances", b"instances", "next_page_token", b"next_page_token"]) -> None: ...

global___ListGpuClusterInstancesResponse = ListGpuClusterInstancesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cic/v1/private_connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.cic.v1 import peering_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_peering__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/cic/v1/private_connection.proto\x12\x13yandex.cloud.cic.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a!yandex/cloud/cic/v1/peering.proto\"\xf1\x03\n\x11PrivateConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x11\n\tregion_id\x18\x06 \x01(\t\x12\x1b\n\x13trunk_connection_id\x18\x07 \x01(\t\x12,\n\x07vlan_id\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cipv4_peering\x18\t \x01(\x0b\x32\x1c.yandex.cloud.cic.v1.Peering\x12N\n\x12ipv4_static_routes\x18\x12 \x03(\x0b\x32\x32.yandex.cloud.cic.v1.PrivateConnection.StaticRoute\x12\x42\n\x06labels\x18\x18 \x03(\x0b\x32\x32.yandex.cloud.cic.v1.PrivateConnection.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x0bStaticRoute\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x14\n\x08next_hop\x18\x02 \x03(\tB\x02\x18\x01J\x04\x08\x04\x10\x05J\x04\x08\n\x10\x12J\x04\x08\x13\x10\x18\x42V\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.private_connection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _PRIVATECONNECTION_LABELSENTRY._options = None
  _PRIVATECONNECTION_LABELSENTRY._serialized_options = b'8\001'
  _PRIVATECONNECTION_STATICROUTE.fields_by_name['next_hop']._options = None
  _PRIVATECONNECTION_STATICROUTE.fields_by_name['next_hop']._serialized_options = b'\030\001'
  _globals['_PRIVATECONNECTION']._serialized_start=137
  _globals['_PRIVATECONNECTION']._serialized_end=634
  _globals['_PRIVATECONNECTION_LABELSENTRY']._serialized_start=518
  _globals['_PRIVATECONNECTION_LABELSENTRY']._serialized_end=563
  _globals['_PRIVATECONNECTION_STATICROUTE']._serialized_start=565
  _globals['_PRIVATECONNECTION_STATICROUTE']._serialized_end=616
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TextEmbeddingRequest(google.protobuf.message.Message):
    """Request for the service to obtain text embeddings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The [model URI](/docs/foundation-models/concepts/embeddings) to be used for obtaining text embeddings."""
    text: builtins.str
    """The input text for which the embedding is requested."""
    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_uri", b"model_uri", "text", b"text"]) -> None: ...

global___TextEmbeddingRequest = TextEmbeddingRequest

@typing.final
class TextEmbeddingResponse(google.protobuf.message.Message):
    """Response containing generated text embedding."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMBEDDING_FIELD_NUMBER: builtins.int
    NUM_TOKENS_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    num_tokens: builtins.int
    """The number of tokens in the input text."""
    model_version: builtins.str
    """The model version changes with each new releases."""
    @property
    def embedding(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """A repeated list of double values representing the embedding."""

    def __init__(
        self,
        *,
        embedding: collections.abc.Iterable[builtins.float] | None = ...,
        num_tokens: builtins.int = ...,
        model_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["embedding", b"embedding", "model_version", b"model_version", "num_tokens", b"num_tokens"]) -> None: ...

global___TextEmbeddingResponse = TextEmbeddingResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Network(google.protobuf.message.Message):
    """A Network resource. For more information, see [Networks](/docs/vpc/concepts/network)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DEFAULT_SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the network."""
    folder_id: builtins.str
    """ID of the folder that the network belongs to."""
    name: builtins.str
    """Name of the network.
    The name is unique within the folder. 
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the network. 0-256 characters long."""
    default_security_group_id: builtins.str
    """ID of default security group for network."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. 
        No more than 64 per resource.
        The maximum string length in characters for each value is 63. 
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63. 
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_security_group_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "default_security_group_id", b"default_security_group_id", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name"]) -> None: ...

global___Network = Network



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.elasticsearch.v1.extension_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    extension_id: builtins.str
    """ID of the extension to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___GetExtensionRequest = GetExtensionRequest

@typing.final
class ListExtensionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list extensions in."""
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the API returns a [ListExtensionsResponse.next_page_token] that can be used to get the next page of results in subsequent [ExtensionService.List] requests.
    """
    page_token: builtins.str
    """Page token that can be used to iterate through multiple pages of results.

    To get the next page of results, set [page_token] to the [ListExtensionsResponse.next_page_token] returned by the previous [ExtensionService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListExtensionsRequest = ListExtensionsRequest

@typing.final
class ListExtensionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """The token that can be used to get the next page of results.

    If the number of results is larger than [ListExtensionsRequest.page_size], use the [next_page_token] as the value for the [ListExtensionsRequest.page_token] in the subsequent [ExtensionService.List] request to iterate through multiple pages of results.

    Each of the subsequent [ExtensionService.List] requests should use the [next_page_token] value returned in the previous request to continue paging through the results.
    """
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension]:
        """Requested list of extensions."""

    def __init__(
        self,
        *,
        extensions: collections.abc.Iterable[yandex.cloud.mdb.elasticsearch.v1.extension_pb2.Extension] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["extensions", b"extensions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListExtensionsResponse = ListExtensionsResponse

@typing.final
class DeleteExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    extension_id: builtins.str
    """ID of the extension to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___DeleteExtensionRequest = DeleteExtensionRequest

@typing.final
class DeleteExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    extension_id: builtins.str
    """ID of the extension to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___DeleteExtensionMetadata = DeleteExtensionMetadata

@typing.final
class UpdateExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    extension_id: builtins.str
    """ID of the extension to update."""
    active: builtins.bool
    """The flag shows whether to make the extension active."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
        active: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___UpdateExtensionRequest = UpdateExtensionRequest

@typing.final
class UpdateExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    extension_id: builtins.str
    """ID of the extension."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___UpdateExtensionMetadata = UpdateExtensionMetadata

@typing.final
class CreateExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    name: builtins.str
    """Name of the extension."""
    uri: builtins.str
    """URI of the zip archive to create the new extension from. Currently only supports links that are stored in Object Storage."""
    disabled: builtins.bool
    """The flag that disables the extension."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        uri: builtins.str = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "disabled", b"disabled", "name", b"name", "uri", b"uri"]) -> None: ...

global___CreateExtensionRequest = CreateExtensionRequest

@typing.final
class CreateExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    extension_id: builtins.str
    """ID of the extension."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_id", b"extension_id"]) -> None: ...

global___CreateExtensionMetadata = CreateExtensionMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MaintenancePolicy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaintenancePolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaintenancePolicy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MAINTENANCE_POLICY_UNSPECIFIED: _MaintenancePolicy.ValueType  # 0
    RESTART: _MaintenancePolicy.ValueType  # 1
    """Restart instance to move it to another host during maintenance"""
    MIGRATE: _MaintenancePolicy.ValueType  # 2
    """Use live migration to move instance to another host during maintenance"""

class MaintenancePolicy(_MaintenancePolicy, metaclass=_MaintenancePolicyEnumTypeWrapper): ...

MAINTENANCE_POLICY_UNSPECIFIED: MaintenancePolicy.ValueType  # 0
RESTART: MaintenancePolicy.ValueType  # 1
"""Restart instance to move it to another host during maintenance"""
MIGRATE: MaintenancePolicy.ValueType  # 2
"""Use live migration to move instance to another host during maintenance"""
global___MaintenancePolicy = MaintenancePolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cic.v1.private_connection_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPrivateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource to return.
    To get the privateConnection ID use a [PrivateConnectionService.List] request.
    """
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___GetPrivateConnectionRequest = GetPrivateConnectionRequest

@typing.final
class ListPrivateConnectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list privateConnections in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListPrivatesConnectionResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListPrivatesConnectionResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Subnet.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPrivateConnectionsRequest = ListPrivateConnectionsRequest

@typing.final
class ListPrivateConnectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListPrivateConnectionsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListPrivateConnectionsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def private_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection]:
        """List of PrivateConnection resources."""

    def __init__(
        self,
        *,
        private_connections: collections.abc.Iterable[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "private_connections", b"private_connections"]) -> None: ...

global___ListPrivateConnectionsResponse = ListPrivateConnectionsResponse
